package org.javacodegeeks.cron;

import org.javacodegeeks.ExampleJob;
import org.quartz.*;
import org.quartz.impl.StdSchedulerFactory;

import java.util.Date;

import static org.quartz.CronScheduleBuilder.cronSchedule;
import static org.quartz.JobBuilder.newJob;
import static org.quartz.TriggerBuilder.newTrigger;

public class CronExample {

    public static void main(String[] args) {
        CronExample cronExample = new CronExample();
        cronExample.run();
    }

    private void run() {
        SchedulerFactory schedulerFactory = new StdSchedulerFactory();
        try {
            Scheduler scheduler = schedulerFactory.getScheduler();
            // jobs can be scheduled before scheduler.start() has been called
            // MyFirstJob will run every 3 seconds
            JobDetail job = newJob(ExampleJob.class).withIdentity("MyFirstJob", "MyFirstGroup").build();
            CronTrigger trigger = newTrigger().withIdentity("MyFirstTrigger", "MyFirstGroup").withSchedule(cronSchedule("0/3 * * * * ?")).build();

            Date date = scheduler.scheduleJob(job, trigger);
            System.out.println(String.format("%s has been scheduled to run at: %s and is repeated based on the cron expression: %s", job.getKey(), date, trigger.getCronExpression()));

            scheduler.start();

            try {
                Thread.sleep(15 * 1000);
                // executing...
            } catch (Exception e) {
                //
            }
            scheduler.shutdown(true);
        } catch (SchedulerException e) {
            e.printStackTrace();
        }
    }
}
